==> haskell-primitive-addr-0.1.0.2-125-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-addr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-addr
version:              0.1.0.2
visibility:           public
id:                   primitive-addr-0.1.0.2-CoqI4c3iPrzDbv4m0BFNUk
key:                  primitive-addr-0.1.0.2-CoqI4c3iPrzDbv4m0BFNUk
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/andrewthad/primitive-addr
synopsis:             Addresses to unmanaged memory
description:
    This library provides the `Data.Primitive.Addr` module
    that was a part of the `primitive` library before `primitive-0.7.0.0`.

category:             Data
abi:                  235aba33c2bf6b2dd08fab902b26741c
exposed:              True
exposed-modules:      Data.Primitive.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-addr
hs-libraries:         HSprimitive-addr-0.1.0.2-CoqI4c3iPrzDbv4m0BFNUk
depends:
    base-4.17.2.1 primitive-0.8.0.0-GOwpVXsLqFV9QZOjtUgUYN

haddock-interfaces:
    /usr/share/doc/haskell-primitive-addr/html/primitive-addr.haddock

haddock-html:         /usr/share/doc/haskell-primitive-addr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-addr-0.1.0.2-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-addr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-addr
version:              0.1.0.2
visibility:           public
id:                   primitive-addr-0.1.0.2-LXV2b4v6W854dFvnzXlFyI
key:                  primitive-addr-0.1.0.2-LXV2b4v6W854dFvnzXlFyI
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/andrewthad/primitive-addr
synopsis:             Addresses to unmanaged memory
description:
    This library provides the `Data.Primitive.Addr` module
    that was a part of the `primitive` library before `primitive-0.7.0.0`.

category:             Data
abi:                  6717a3e06480d78655afce6121f42bf4
exposed:              True
exposed-modules:      Data.Primitive.Addr
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-addr-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-addr
hs-libraries:         HSprimitive-addr-0.1.0.2-LXV2b4v6W854dFvnzXlFyI
depends:
    base-4.17.2.1 primitive-0.8.0.0-8L1oTAgt3Zw9WwfojBIh27

haddock-interfaces:
    /usr/share/doc/haskell-primitive-addr/html/primitive-addr.haddock

haddock-html:         /usr/share/doc/haskell-primitive-addr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
